import React from "react";
import ReactDOM from "react-dom";
import "tailwindcss/tailwind.css";
import "./index.css";
import App from "./App";

ReactDOM.render(<App />, document.getElementById("app"));
